"use strict";
// *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
// *** Do not edit by hand unless you're certain you know what you are doing! ***
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultPrivileges = void 0;
const pulumi = require("@pulumi/pulumi");
const utilities = require("./utilities");
/**
 * The ``postgresql.DefaultPrivileges`` resource creates and manages default privileges given to a user for a database schema.
 *
 * > **Note:** This resource needs Postgresql version 9 or above.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const readOnlyTables = new postgresql.DefaultPrivileges("read_only_tables", {
 *     role: "test_role",
 *     database: "test_db",
 *     schema: "public",
 *     owner: "db_owner",
 *     objectType: "table",
 *     privileges: ["SELECT"],
 * });
 * ```
 *
 * ## Examples
 *
 * ### Grant default privileges for tables to "currentRole" role:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const grantTablePrivileges = new postgresql.DefaultPrivileges("grant_table_privileges", {
 *     database: exampleDb.name,
 *     role: "current_role",
 *     owner: "owner_role",
 *     schema: "public",
 *     objectType: "table",
 *     privileges: [
 *         "SELECT",
 *         "INSERT",
 *         "UPDATE",
 *     ],
 * });
 * ```
 * Whenever the `ownerRole` creates a new table in the `public` schema, the `currentRole` is automatically granted SELECT, INSERT, and UPDATE privileges on that table.
 *
 * ### Revoke default privileges for functions for "public" role:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const revokePublic = new postgresql.DefaultPrivileges("revoke_public", {
 *     database: exampleDb.name,
 *     role: "public",
 *     owner: "object_owner",
 *     objectType: "function",
 *     privileges: [],
 * });
 * ```
 */
class DefaultPrivileges extends pulumi.CustomResource {
    /**
     * Get an existing DefaultPrivileges resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name, id, state, opts) {
        return new DefaultPrivileges(name, state, Object.assign(Object.assign({}, opts), { id: id }));
    }
    /**
     * Returns true if the given object is an instance of DefaultPrivileges.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj) {
        if (obj === undefined || obj === null) {
            return false;
        }
        return obj['__pulumiType'] === DefaultPrivileges.__pulumiType;
    }
    constructor(name, argsOrState, opts) {
        let resourceInputs = {};
        opts = opts || {};
        if (opts.id) {
            const state = argsOrState;
            resourceInputs["database"] = state ? state.database : undefined;
            resourceInputs["objectType"] = state ? state.objectType : undefined;
            resourceInputs["owner"] = state ? state.owner : undefined;
            resourceInputs["privileges"] = state ? state.privileges : undefined;
            resourceInputs["role"] = state ? state.role : undefined;
            resourceInputs["schema"] = state ? state.schema : undefined;
            resourceInputs["withGrantOption"] = state ? state.withGrantOption : undefined;
        }
        else {
            const args = argsOrState;
            if ((!args || args.database === undefined) && !opts.urn) {
                throw new Error("Missing required property 'database'");
            }
            if ((!args || args.objectType === undefined) && !opts.urn) {
                throw new Error("Missing required property 'objectType'");
            }
            if ((!args || args.owner === undefined) && !opts.urn) {
                throw new Error("Missing required property 'owner'");
            }
            if ((!args || args.privileges === undefined) && !opts.urn) {
                throw new Error("Missing required property 'privileges'");
            }
            if ((!args || args.role === undefined) && !opts.urn) {
                throw new Error("Missing required property 'role'");
            }
            resourceInputs["database"] = args ? args.database : undefined;
            resourceInputs["objectType"] = args ? args.objectType : undefined;
            resourceInputs["owner"] = args ? args.owner : undefined;
            resourceInputs["privileges"] = args ? args.privileges : undefined;
            resourceInputs["role"] = args ? args.role : undefined;
            resourceInputs["schema"] = args ? args.schema : undefined;
            resourceInputs["withGrantOption"] = args ? args.withGrantOption : undefined;
        }
        opts = pulumi.mergeOptions(utilities.resourceOptsDefaults(), opts);
        const aliasOpts = { aliases: [{ type: "postgresql:index/defaultPrivileg:DefaultPrivileg" }] };
        opts = pulumi.mergeOptions(opts, aliasOpts);
        super(DefaultPrivileges.__pulumiType, name, resourceInputs, opts);
    }
}
exports.DefaultPrivileges = DefaultPrivileges;
/** @internal */
DefaultPrivileges.__pulumiType = 'postgresql:index/defaultPrivileges:DefaultPrivileges';
//# sourceMappingURL=defaultPrivileges.js.map