"use strict";
// *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
// *** Do not edit by hand unless you're certain you know what you are doing! ***
Object.defineProperty(exports, "__esModule", { value: true });
exports.Grant = void 0;
const pulumi = require("@pulumi/pulumi");
const utilities = require("./utilities");
/**
 * The ``postgresql.Grant`` resource creates and manages privileges given to a user for a database schema.
 *
 * See [PostgreSQL documentation](https://www.postgresql.org/docs/current/sql-grant.html)
 *
 * > **Note:** This resource needs Postgresql version 9 or above.
 * **Note:** Using column & table grants on the _same_ table with the _same_ privileges can lead to unexpected behaviours.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * // Grant SELECT privileges on 2 tables
 * const readonlyTables = new postgresql.Grant("readonly_tables", {
 *     database: "test_db",
 *     role: "test_role",
 *     schema: "public",
 *     objectType: "table",
 *     objects: [
 *         "table1",
 *         "table2",
 *     ],
 *     privileges: ["SELECT"],
 * });
 * // Grant SELECT & INSERT privileges on 2 columns in 1 table
 * const readInsertColumn = new postgresql.Grant("read_insert_column", {
 *     database: "test_db",
 *     role: "test_role",
 *     schema: "public",
 *     objectType: "column",
 *     objects: ["table1"],
 *     columns: [
 *         "col1",
 *         "col2",
 *     ],
 *     privileges: [
 *         "UPDATE",
 *         "INSERT",
 *     ],
 * });
 * ```
 *
 * ## Examples
 *
 * Revoke default accesses for public schema:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const revokePublic = new postgresql.Grant("revoke_public", {
 *     database: "test_db",
 *     role: "public",
 *     schema: "public",
 *     objectType: "schema",
 *     privileges: [],
 * });
 * ```
 */
class Grant extends pulumi.CustomResource {
    /**
     * Get an existing Grant resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name, id, state, opts) {
        return new Grant(name, state, Object.assign(Object.assign({}, opts), { id: id }));
    }
    /**
     * Returns true if the given object is an instance of Grant.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj) {
        if (obj === undefined || obj === null) {
            return false;
        }
        return obj['__pulumiType'] === Grant.__pulumiType;
    }
    constructor(name, argsOrState, opts) {
        let resourceInputs = {};
        opts = opts || {};
        if (opts.id) {
            const state = argsOrState;
            resourceInputs["columns"] = state ? state.columns : undefined;
            resourceInputs["database"] = state ? state.database : undefined;
            resourceInputs["objectType"] = state ? state.objectType : undefined;
            resourceInputs["objects"] = state ? state.objects : undefined;
            resourceInputs["privileges"] = state ? state.privileges : undefined;
            resourceInputs["role"] = state ? state.role : undefined;
            resourceInputs["schema"] = state ? state.schema : undefined;
            resourceInputs["withGrantOption"] = state ? state.withGrantOption : undefined;
        }
        else {
            const args = argsOrState;
            if ((!args || args.database === undefined) && !opts.urn) {
                throw new Error("Missing required property 'database'");
            }
            if ((!args || args.objectType === undefined) && !opts.urn) {
                throw new Error("Missing required property 'objectType'");
            }
            if ((!args || args.privileges === undefined) && !opts.urn) {
                throw new Error("Missing required property 'privileges'");
            }
            if ((!args || args.role === undefined) && !opts.urn) {
                throw new Error("Missing required property 'role'");
            }
            resourceInputs["columns"] = args ? args.columns : undefined;
            resourceInputs["database"] = args ? args.database : undefined;
            resourceInputs["objectType"] = args ? args.objectType : undefined;
            resourceInputs["objects"] = args ? args.objects : undefined;
            resourceInputs["privileges"] = args ? args.privileges : undefined;
            resourceInputs["role"] = args ? args.role : undefined;
            resourceInputs["schema"] = args ? args.schema : undefined;
            resourceInputs["withGrantOption"] = args ? args.withGrantOption : undefined;
        }
        opts = pulumi.mergeOptions(utilities.resourceOptsDefaults(), opts);
        super(Grant.__pulumiType, name, resourceInputs, opts);
    }
}
exports.Grant = Grant;
/** @internal */
Grant.__pulumiType = 'postgresql:index/grant:Grant';
//# sourceMappingURL=grant.js.map