import * as pulumi from "@pulumi/pulumi";
import * as inputs from "./types/input";
import * as outputs from "./types/output";
export declare class Schema extends pulumi.CustomResource {
    /**
     * Get an existing Schema resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SchemaState, opts?: pulumi.CustomResourceOptions): Schema;
    /**
     * Returns true if the given object is an instance of Schema.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Schema;
    /**
     * The DATABASE in which where this schema will be created. (Default: The database used by your `provider` configuration)
     */
    readonly database: pulumi.Output<string>;
    /**
     * When true, will also drop all the objects that are contained in the schema. (Default: false)
     */
    readonly dropCascade: pulumi.Output<boolean | undefined>;
    /**
     * When true, use the existing schema if it exists. (Default: true)
     */
    readonly ifNotExists: pulumi.Output<boolean | undefined>;
    /**
     * The name of the schema. Must be unique in the PostgreSQL
     * database instance where it is configured.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ROLE who owns the schema.
     */
    readonly owner: pulumi.Output<string>;
    /**
     * Can be specified multiple times for each policy.  Each
     * policy block supports fields documented below.
     *
     * @deprecated Use postgresql.Grant resource instead (with object_type="schema")
     */
    readonly policies: pulumi.Output<outputs.SchemaPolicy[]>;
    /**
     * Create a Schema resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: SchemaArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Schema resources.
 */
export interface SchemaState {
    /**
     * The DATABASE in which where this schema will be created. (Default: The database used by your `provider` configuration)
     */
    database?: pulumi.Input<string>;
    /**
     * When true, will also drop all the objects that are contained in the schema. (Default: false)
     */
    dropCascade?: pulumi.Input<boolean>;
    /**
     * When true, use the existing schema if it exists. (Default: true)
     */
    ifNotExists?: pulumi.Input<boolean>;
    /**
     * The name of the schema. Must be unique in the PostgreSQL
     * database instance where it is configured.
     */
    name?: pulumi.Input<string>;
    /**
     * The ROLE who owns the schema.
     */
    owner?: pulumi.Input<string>;
    /**
     * Can be specified multiple times for each policy.  Each
     * policy block supports fields documented below.
     *
     * @deprecated Use postgresql.Grant resource instead (with object_type="schema")
     */
    policies?: pulumi.Input<pulumi.Input<inputs.SchemaPolicy>[]>;
}
/**
 * The set of arguments for constructing a Schema resource.
 */
export interface SchemaArgs {
    /**
     * The DATABASE in which where this schema will be created. (Default: The database used by your `provider` configuration)
     */
    database?: pulumi.Input<string>;
    /**
     * When true, will also drop all the objects that are contained in the schema. (Default: false)
     */
    dropCascade?: pulumi.Input<boolean>;
    /**
     * When true, use the existing schema if it exists. (Default: true)
     */
    ifNotExists?: pulumi.Input<boolean>;
    /**
     * The name of the schema. Must be unique in the PostgreSQL
     * database instance where it is configured.
     */
    name?: pulumi.Input<string>;
    /**
     * The ROLE who owns the schema.
     */
    owner?: pulumi.Input<string>;
    /**
     * Can be specified multiple times for each policy.  Each
     * policy block supports fields documented below.
     *
     * @deprecated Use postgresql.Grant resource instead (with object_type="schema")
     */
    policies?: pulumi.Input<pulumi.Input<inputs.SchemaPolicy>[]>;
}
